import transaction
import testing.postgresql
import webtest
from pyramid.paster import get_app
from sqlalchemy import create_engine

from .models import (
    DBSession,
    Base,
    Person,
    Blog,
    Post,
    Comment
)

from . import test_data

class Playpen():
    '''Create a temporary database and server for play/dev/test purposes.
    '''
    def __init__(self):
        '''Create a test DB and import data.'''
        # Create a new database somewhere in /tmp
        self.postgresql = testing.postgresql.Postgresql(port=7654)
        self.engine = create_engine(self.postgresql.url())
        DBSession.configure(bind=self.engine)

        self.app = get_app('testing.ini')
        self.test_app = webtest.TestApp(self.app)

    def destroy(self):
        '''Throw away test DB.'''
        DBSession.close()
        self.postgresql.stop()

    def start(self):
        '''Add test data and start transaction.'''
        Base.metadata.create_all(self.engine)
        # Add some basic test data.
        test_data.add_to_db()
        transaction.begin()

    def stop(self):
        '''Stop transaction and drop test data.'''
        transaction.abort()
        Base.metadata.drop_all(self.engine)
